@@ -63,7 +63,7 @@ class AMQPPipeline(object):
                 queue_data = {}
                 if amqp_queue_use_item == True:
                     data = item
-                    queue_data = json.dumps(data.to_json_str(), ensure_ascii=False)
+                    queue_data = data.to_json_str()
                 else:
                     queue_data = json.dumps({
                         "filename": item.get('oss_filename'),
